@@ -61,7 +61,7 @@ void authfail_report()
    sprintf(per,"%s/periodo",dirname);
    sprintf(report,"%s/authfail.html",dirname);
 
-   sprintf(csort,"sort -b -T %s -k 3,3 -k 5,5 -o %s %s", TempDir, authfail_in, tmp4);
+   sprintf(csort,"export LC_ALL=C;sort -b -T %s -k 3,3 -k 5,5 -o %s %s", TempDir, authfail_in, tmp4);
    system(csort);
    unlink(tmp4);
 
