@@ -1,11 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void gen_denied_report(const char *dirname, int debug, const char *outdir, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *DateFormat)
+void gen_denied_report()
 {
 
    FILE *fp_in = NULL, *fp_ou = NULL;
@@ -22,11 +39,13 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
    char oip[MAXLEN];
    char user[MAXLEN];
    char ouser[MAXLEN];
+   char ouser2[MAXLEN];
    char data[15];
    char hora[15];
    char ftime[128];
    char *str;
    int  z=0;
+   int  count=0;
 
    ouser[0]='\0';
 
@@ -57,36 +76,32 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
      exit(1);
    }
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
    fputs("<html>\n",fp_ou);
    fputs("<head>\n",fp_ou);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs(html,fp_ou);
+   css(fp_ou);
    fputs("</head>\n",fp_ou);
 
-   if(strlen(FontFace) > 0) {
-      sprintf(url,"<font face=%s>\n",FontFace);
-      fputs(url,fp_ou);
-   }
-
    sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs(url,fp_ou);
 
    fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
 
    if(strlen(LogoImage) > 0) {
-      sprintf(url,"<tr><th><img src='%s' border=0 align=absmiddle width=%s height=%s>		\
-		   <font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      sprintf(url,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(url,fp_ou);
    }
 
-   sprintf(url,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   show_sarg(fp_ou, "..");
+   sprintf(url,"<tr><th class=\"title\">%s</b></th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s color=%s>%s: %s</font></td></tr>\n", HeaderBgColor,FontSize,HeaderColor,text[89],periodo);
+   sprintf(url,"<tr><td class=\"header\">%s: %s</td></tr>\n",text[89],periodo);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><th bgcolor=%s align=center><font size=%s color=red>%s</font>		\
-		 <font size=%s>%s</font></th></tr>\n",	\
-		HeaderBgColor,FontSize,text[46],FontSize,text[55]);
+   sprintf(url,"<tr><th class=\"header3\">%s %s</th></tr>\n",text[46],text[55]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
@@ -94,14 +109,7 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><th bgcolor=%s><font size=%s color=%s>%s</font></th>		\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th>			\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th>			\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",		\
-		HeaderBgColor,FontSize,HeaderColor,text[98],						\
-		HeaderBgColor,FontSize,HeaderColor,text[111],						\
-		HeaderBgColor,FontSize,HeaderColor,text[110],						\
-		HeaderBgColor,FontSize,HeaderColor,text[91]);
+   sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[98],text[111],text[110],text[91]);
    fputs(url,fp_ou);
 
    while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
@@ -148,25 +156,29 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
          } else strcpy(name,user);
       } else strcpy(name,user);
 
-      sprintf(html2,"<tr><td bgcolor=%s><font size=%s>%s</font></td> \
-			<td bgcolor=%s><font size=%s>%s</font></td> \
-			<td bgcolor=%s><font size=%s>%s-%s</font></td> \
-			<td bgcolor=%s><font size=%s><a href=\"%s\">%s</a></font></td></th>\n",
-			TxBgColor,FontSize,name,
-			TxBgColor,FontSize,ip,
-			TxBgColor,FontSize,data,hora,
-			TxBgColor,FontSize,url,url);
+      if(DeniedReportLimit) {
+         if(strcmp(ouser2,name) == 0) {
+            count++; 
+         } else {
+            count=1;
+            strcpy(ouser2,name);
+         }
+         if(count >= DeniedReportLimit)
+            continue;
+      }
+
+      if(strlen(BlockIt) > 0)
+         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url);
+      else BlockImage[0]='\0';
+
+      sprintf(html2,"<tr><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s-%s</td><td class=\"data2\">%s<a href=\"%s\">%s</a></td></th>\n",name,ip,data,hora,BlockImage,url,url);
       fputs(html2,fp_ou);
    }
 
    fputs("</table>\n",fp_ou);
 
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-      zdate(ftime, DateFormat);
-      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n", text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(html,fp_ou);
-   }
-   fputs("</html>\n",fp_ou);
+   show_info(fp_ou);
+   fputs("</body></html>\n",fp_ou);
 
    fclose(fp_in);
    fclose(fp_ou);
