@@ -146,7 +146,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    fclose(fp_in);
    fclose(fp_top2);
 
-   sprintf(csort,"sort -n -T %s -r -k 2,2 -o %s %s", TempDir, top1, top2);
+   sprintf(csort,"export LC_ALL=C;sort -n -T %s -r -k 2,2 -o %s %s", TempDir, top1, top2);
    system(csort);
 
    unlink(top2);
