@@ -713,6 +713,12 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"ulimit") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(Ulimit,buf);
+         fixnone(Ulimit);
+         return;
+      }
     
       return;
 }
