@@ -353,9 +353,9 @@ void greport_day(char *user, int *iprel, int *ipuser)
    sprintf(wdirname,"%s/%s.day",tmp,user);
    sprintf(tmp5,"%s/%s.graph",tmp,user);
 
-   sprintf(csort,"sort -t'/' -k 2,2 -o %s %s",tmp5,wdirname);
+   sprintf(csort,"export LC_ALL=C;sort -t'/' -k 2,2 -o %s %s",tmp5,wdirname);
    if(strcmp(DateFormat,"e") == 0)
-      sprintf(csort,"sort -t'/' -k 1,1 -o %s %s",tmp5,wdirname);
+      sprintf(csort,"export LC_ALL=C;sort -t'/' -k 1,1 -o %s %s",tmp5,wdirname);
 
    system(csort);
 
