@@ -367,13 +367,13 @@ void htmlrel()
                siteind[z2]=str[z1];
                z2++;
             }
-            sprintf(href2,"<a href='tt%s-%s.html'>",usuario,siteind);
+            sprintf(href2,"<a href=\"tt%s-%s.html\"><img src=\"../../images/datetime.png\" border=\"0\" title=\"%s %s\"></a>",usuario,siteind,ltext110,text[55]);
          } else {
             bzero(href2, MAXLEN);
             bzero(ltext110, 50);
          } 
 
-         sprintf(val2,"%s%s",href2,ltext110);
+         sprintf(val2,"%s",href2);
          sprintf(val3,"%3.2f%%",perc);
          sprintf(val4,"%3.2f%%",inperc);
          sprintf(val5,"%3.2f%%",ouperc);
@@ -446,7 +446,7 @@ void htmlrel()
             fclose(fp_ip);
             fclose(fp_ip2);
 
-            sprintf(csort,"sort -n -T %s -k 1,1 -k 5,5 -o %s %s",TempDir,tmp3,tmp2);
+            sprintf(csort,"export LC_ALL=C;sort -n -T %s -k 1,1 -k 5,5 -o %s %s",TempDir,tmp3,tmp2);
             system(csort);
    
             if ((fp_ip = fopen(tmp3, "r")) == 0) {
