@@ -19,6 +19,9 @@
 #if HAVE_TIME_H
 #include <time.h>
 #endif
+#if HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#endif
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -49,6 +52,9 @@
 #if HAVE_CTYPE_H
 #include <ctype.h>
 #endif
+#if HAVE_ERRNO_H
+#include <errno.h>
+#endif
 #if HAVE_GD_H
 #include <gd.h>
 #define HAVE_GD
@@ -249,6 +255,8 @@ char wentp[512];
 char addr[MAXLEN];
 char suffix[10];
 char download_url[MAXLEN];
+char Ulimit[5];
+char cmd[255];
 int  excode;
 int  idate;
 int  smartfilter;
@@ -263,6 +271,8 @@ int  color3;
 int  z1, z2, z3;
 int  ttopen;
 int  ind2;
+int  sarglog;
+int  isalog;
 int  dfrom; 
 int  duntil;
 int  dataonly;
@@ -285,6 +295,7 @@ int  SiteUsersReportLimit;
 int  SquidGuardReportLimit;
 int  UserReportLimit;
 int  download_flag;
+long l1, l2;
 float perc;
 
 long long int twork;
