@@ -109,9 +109,9 @@ void geraindex()
    (void)closedir( dirp );
 
    if(strcmp(IndexSortOrder,"A") == 0)
-      sprintf(html,"sort -t';' -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+      sprintf(html,"export LC_ALL=C;sort -t';' -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
    else
-      sprintf(html,"sort -t';' -r -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
+      sprintf(html,"export LC_ALL=C;sort -t';' -r -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
 
    system(html);
 
@@ -163,7 +163,7 @@ void geraindex()
       getword(tbytes,buf,';');
       getword(media,buf,';');
 
-      sprintf(html,"<tr><td class=\"data\"><a href='%s/%s'>%s</a></td><td class=\"data\">%s</td> \
+      sprintf(html,"<tr><td class=\"data2\"><a href='%s/%s'>%s</a></td><td class=\"data2\">%s</td> \
 	<td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n", \
 	period,ReplaceIndex,period,data,tuser,tbytes,media);
       fputs(html,fp_ou);
