@@ -64,7 +64,7 @@ void mklastlog()
    (void)closedir( dirp );
    fclose(fp_ou);
    
-   sprintf(buf,"sort -n -k 1,1 -o %slastlog %s",outdir,temp);
+   sprintf(buf,"export LC_ALL=C;sort -n -k 1,1 -o %slastlog %s",outdir,temp);
    system(buf);
 
    unlink(temp);
