@@ -1,7 +1,10 @@
 /*
- * AUTHOR: Pedro Lineu Orso		                orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso		              rso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator	           http://sarg-squid.org
+ * 
+ * SARG donations:
+ *      please look at http://sarg.sourceforge.net/donations.php 
  * ---------------------------------------------------------------------
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -108,8 +111,8 @@ int main(argc,argv)
    int  idata=0;
    int  narq=0;
    int  iarq=0;
-   int  sarglog=0;
    int  exstring=0;
+   int  i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0;
    long totregsl=0; 
    long totregsg=0;
    long totregsx=0;
@@ -120,7 +123,7 @@ int main(argc,argv)
    unsigned long nreg=0;
    off_t recs1=0;
    unsigned long recs2=0;
-
+   struct rlimit rl;
    int OutputNonZero = REPORT_EVERY_X_LINES ;
 
    BgImage[0]='\0';
@@ -141,6 +144,7 @@ int main(argc,argv)
    UserTabFile[0]='\0';
    BlockIt[0]='\0';
    ExternalCSSFile[0]='\0';
+   SquidGuardLogFormat[0]='\0';
 
    strcpy(AccessLog,"/usr/local/squid/var/logs/access.log");
    sprintf(ExcludeCodes,"%s/exclude_codes",SYSCONFDIR);
@@ -203,6 +207,7 @@ int main(argc,argv)
    strcpy(Require,"require user admin %u");
    strcpy(DownloadSuffix,"zip,arj,bzip,gz,ace,doc,iso,adt,bin,cab,dot,drv$,lha,lzh,mdb,mso,ppt,rtf,src,shs,sys,exe,dll,mp3,avi,mpg,mpeg");
    strcpy(Graphs,"yes");
+   strcpy(Ulimit,"20000");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -246,6 +251,8 @@ int main(argc,argv)
    color1=0;
    color2=0;
    color3=0;
+   sarglog=0;
+   isalog=0;
 
    bzero(IncludeUsers, MAXLEN);
    bzero(ExcludeString, MAXLEN);
@@ -256,7 +263,7 @@ int main(argc,argv)
    language_load(language);
    strcpy(Title,text[88]);
 
-   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:o:r:s:t:w:hijmnpxyz")) != -1){
+   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:o:r:s:t:w:hijmnpvxyz")) != -1){
       switch(ch)
       {
          case 'a':
@@ -317,6 +324,9 @@ int main(argc,argv)
          case 'u':
             strcpy(us,optarg);
             break;
+         case 'v':
+            version();
+            break;
          case 'w':
             strcpy(tmp,optarg);
             break;
@@ -353,7 +363,7 @@ int main(argc,argv)
       sprintf(ConfigFile,"%s/sarg.conf",SYSCONFDIR);
     else {
       if(access(ConfigFile, R_OK) != 0) {
-         sprintf(msg,"Cannot open config file: %s",ConfigFile);
+         sprintf(msg,"Cannot open config file: %s - %s",ConfigFile,strerror(errno));
          debuga(msg);
          exit(1);
       }
@@ -399,7 +409,7 @@ int main(argc,argv)
       fprintf(stderr, "SARG: LastLog............= %s\n",LastLog);
       fprintf(stderr, "SARG:\n");
    }
-
+ 
    dataonly=0;
    if(DataFile[0] != '\0');
       dataonly++;
@@ -441,9 +451,15 @@ int main(argc,argv)
 
    if(hexclude[0] == '\0')
       strcpy(hexclude,ExcludeHosts);
-   if(access(hexclude, R_OK) == 0) {
-      gethexclude(hexclude,debug);
-      fhost++;
+   if(strlen(hexclude) > 0) {
+      if(access(hexclude, R_OK) != 0) {
+         sprintf(msg,"Cannot open exclude_hosts file: %s - %s",hexclude,strerror(errno));
+         debuga(msg);
+         exit(1);
+      } else {
+         gethexclude(hexclude,debug);
+         fhost++;
+      }
    }
 
    if(ReportType[0] == '\0')
@@ -623,13 +639,39 @@ int main(argc,argv)
       debuga(msg);
    }
 
+#if defined(__FreeBSD__)
+   getrlimit (RLIMIT_OFILE, &rl);
+#else
+   getrlimit (RLIMIT_NOFILE, &rl);
+#endif
+   l1 = rl.rlim_cur;
+   l2 = rl.rlim_max;
+
+   rl.rlim_cur = atol(Ulimit);
+   rl.rlim_max = atol(Ulimit);
+#if defined(__FreeBSD__)
+   if(setrlimit (RLIMIT_OFILE, &rl) == -1) {
+#else
+   if(setrlimit (RLIMIT_NOFILE, &rl) == -1) {
+#endif
+      sprintf(msg,"setrlimit error - %s\n",strerror(errno));
+      debuga(msg);
+   }
+
+   if(debug) {
+      sprintf(msg,"Maximum file descriptor: cur=%ld max=%ld, changed to cur=%ld max=%ld",l1,l2,rl.rlim_cur,rl.rlim_max);
+      debuga(msg);
+   }
+
+//   system("export LC_ALL=C");
+
    if(UserTabFile[0] != '\0') {
       if(debug) {
          sprintf(msg,"%s: %s",text[86],UserTabFile);
          debuga(msg);
       }
       if((fp_usr=fopen(UserTabFile,"r"))==NULL) {
-        fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[45],UserTabFile);
+        fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[45],UserTabFile,strerror(errno));
         exit(1);
       }
       nreg = lseek(fileno(fp_usr), 0, SEEK_END);
@@ -680,10 +722,14 @@ int main(argc,argv)
 #else
    if((fp_in=fopen(arq,"r"))==NULL) {
 #endif
-     fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[8],arq);
+     fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[8],arq,strerror(errno));
      exit(1);
    }
    fgets(bufz,sizeof(bufz),fp_in);
+   if(!isalog) {
+      if(strncmp(bufz,"#Software: Microsoft(R)",23) == 0)
+         isalog++;
+   }
    if(strncmp(bufz,"*** SARG Log ***",16) == 0) {
       getword(val2,arqtt,'-');
       getword(val2,arqtt,'_');
@@ -700,7 +746,7 @@ int main(argc,argv)
       }
       sprintf(arq_log,"%s/sarg_temp.log",ParsedOutputLog);
       if((fp_log=fopen(arq_log,"w"))==NULL) {
-        fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[8],arq_log);
+        fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[8],arq_log,strerror(errno));
         exit(1);
       }
       fputs("*** SARG Log ***\n",fp_log);
@@ -708,7 +754,7 @@ int main(argc,argv)
 
    if(strstr(ReportType,"denied") != 0) {
       if((fp_denied=fopen(tmp4,"w"))==NULL) {
-         fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[45],tmp4);
+         fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[45],tmp4,strerror(errno));
          exit(1);
       }
    }
@@ -716,7 +762,7 @@ int main(argc,argv)
    if(DataFile[0]=='\0') {
       if(strstr(ReportType,"denied") != 0 || strstr(ReportType,"auth_failures") != 0) {
          if((fp_authfail=fopen(tmp6,"w"))==NULL) {
-            fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[45],tmp6);
+            fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[45],tmp6,strerror(errno));
             exit(1);
          }
       }
@@ -738,10 +784,10 @@ int main(argc,argv)
     
    while(fgets(bufz,sizeof(bufz),fp_in)!=NULL) {
 	recs2++;
-	if( bool_ShowReadStatistics && ! --OutputNonZero ) {
+	if( bool_ShowReadStatistics && ! --OutputNonZero) {
            perc = recs2 * 100 ;
            perc = perc / recs1 ;
-	   printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,perc);
+   	   printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,perc);
            fflush (stdout);
            OutputNonZero = REPORT_EVERY_X_LINES ;
         }
@@ -788,7 +834,7 @@ int main(argc,argv)
         if(debugm)
        	   printf("BUF=%s\n",bufz);
 
-        if(!sarglog) {
+        if(!sarglog && !isalog) {
            getword(data,bufz,' ');
            if((str=(char *) strstr(data, ".")) != (char *) NULL ) {
               if((str=(char *) strstr(str+1, ".")) != (char *) NULL ) {
@@ -828,7 +874,7 @@ int main(argc,argv)
 	      getword(user,bufz,' ');
 	      squid_log=1;
 	   }
-        } else {
+        } else if(!isalog) {
 	   getword(data,bufz,' ');
 	   getword(hora,bufz,' ');
 	   getword(user,bufz,' ');
@@ -838,6 +884,49 @@ int main(argc,argv)
 	   getword(code,bufz,' ');
 	   getword(elap,bufz,' ');
 	   getword(smartfilter,bufz,' ');
+        } else if(isalog) {
+           if(!i0) {
+              getword(val1,bufz,' ');
+              while(strstr(bufz,"\t") != 0) {
+                 getword(val1,bufz,'\t');
+                 i0++;
+                 if(strcmp(val1,"c-ip") == 0) i1=i0;
+                 if(strcmp(val1,"cs-username") == 0) i2=i0;
+                 if(strcmp(val1,"date") == 0) i3=i0;
+                 if(strcmp(val1,"time") == 0) i4=i0;
+                 if(strcmp(val1,"time-taken") == 0) i5=i0;
+                 if(strcmp(val1,"sc-bytes") == 0) i6=i0;
+                 if(strcmp(val1,"cs-uri") == 0) i7=i0;
+                 if(strcmp(val1,"sc-status") == 0) i8=i0;
+              }
+           }
+           fgets(bufz,sizeof(bufz),fp_in);
+           strcpy(val1,bufz);
+           for(x=0; x<=i1-1; x++) getword3(ip,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i2-1; x++) getword3(user,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i3-1; x++) getword3(data,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i4-1; x++) getword3(hora,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i5-1; x++) getword3(elap,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i6-1; x++) getword3(tam,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i7-1; x++) getword3(url,val1,'\t');
+           strcpy(val1,bufz);
+           for(x=0; x<=i8-1; x++) getword3(code,val1,'\t');
+           
+           if(strcmp(code,"401") == 0 || strcmp(code,"403") == 0 || strcmp(code,"407") == 0) {
+              sprintf(val1,"DENIED/%s",code);
+              strcpy(code,val1);
+           }
+           getword(ano,data,'-');
+           getword(mes,data,'-');
+           strcpy(dia,data);
+           conv_month_name(mes);
+           sprintf(data," %s/%s/%s:%s",dia,mes,ano,hora);
         }
 
 	// include_users
@@ -889,7 +978,9 @@ int main(argc,argv)
         if(strlen(DownloadSuffix)) {
            suffix[0]='\0';
            download_flag=0;
-           strncpy(suffix,url+strlen(url)-3,3);
+           if(strncmp(url+strlen(url)-4,".",1) == 0)
+              strcpy(suffix,url+strlen(url)-3);
+           else strcpy(suffix,url+strlen(url)-4);
            if(strstr(DownloadSuffix,suffix) != 0) {
               strcpy(download_url,url);
               download_flag=1;
@@ -908,7 +999,7 @@ int main(argc,argv)
         }
 
         if(!sarglog) {
-           if(!common) {
+           if(!common && !isalog) {
               tt=atoi(data);
               t=localtime(&tt);
 
@@ -965,7 +1056,7 @@ int main(argc,argv)
  	   }
            if(fhost) {
               l=vhexclude(excludefile,ip);
-              l=vhexclude(excludefile,url);
+              if(l) l=vhexclude(excludefile,url);
               if(!l)
 	         totregsx++;
            }
@@ -1044,44 +1135,28 @@ int main(argc,argv)
 #else
               if((fp_ou=fopen(tmp3,"a"))==NULL) {
 #endif
-                fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
+                fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[9],tmp3,strerror(errno));
                 exit(1);
               }
               fputs(bufz,fp_ou);
 
 #else
-// Check to see if user is the same of the previous line
-
-                  if ( strcmp ( user , sz_Last_User ) != 0 )
-                  {
-                        // NOT MATCHED - DIFFERENT USER
-                        // printf( "NOT MATCHED !!!!\n" ) ;
-                        // Close other file
+                  if ( strcmp ( user , sz_Last_User ) != 0 ) {
                         if ( fp_Write_User )
                                 fclose( fp_Write_User ) ;
-                        // Create new file name
                         sprintf (tmp3, "%s/sarg/%s.unsort", tmp, user);
 
-                        // Open new file name
 #if defined(HAVE_FOPEN64)
-                        if ((fp_Write_User = fopen64 (tmp3, "a")) == NULL)
-                        {
+                        if ((fp_Write_User = fopen64 (tmp3, "a")) == NULL) {
 #else
-                        if ((fp_Write_User = fopen (tmp3, "a")) == NULL)
-                        {
+                        if ((fp_Write_User = fopen (tmp3, "a")) == NULL) {
 #endif
-                              fprintf (stderr, "%s: (log) %s: %s\n", argv[0], text[9], tmp3);
+                              fprintf (stderr, "%s: (log) %s: %s - %s\n", argv[0], text[9], tmp3, strerror(errno));
                                 exit (1);
                         }
-//                        EachUserFopen++ ;
-
-                        // Store actual user for next iteration
                         strcpy( sz_Last_User , user ) ;
                   }
-
-                  // Store value
                   fputs (bufz, fp_Write_User);
-
 #endif
 
               if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog)
@@ -1102,25 +1177,21 @@ int main(argc,argv)
 #else
                  if((fp_ou=fopen(tmp3,"a"))==NULL) {
 #endif
-                    fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
+                    fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[9],tmp3,strerror(errno));
                     exit(1);
                  }
                  fputs(bufz,fp_ou);
                  fclose(fp_ou);
 #else
-                 if ( ! fp_Download_Unsort )
-                 {
+                 if ( ! fp_Download_Unsort ) {
 #if defined(HAVE_FOPEN64)
-                      if ((fp_Download_Unsort = fopen64 ( sz_Download_Unsort, "a")) == NULL)
-                      {
+                      if ((fp_Download_Unsort = fopen64 ( sz_Download_Unsort, "a")) == NULL) {
 #else
-                      if ((fp_Download_Unsort = fopen (sz_Download_Unsort, "a")) == NULL)
-                      {
+                      if ((fp_Download_Unsort = fopen (sz_Download_Unsort, "a")) == NULL) {
 #endif
-                          fprintf (stderr, "%s: (log) %s: %s\n", argv[0],
-                                   text[9], tmp3);
+                          fprintf (stderr, "%s: (log) %s: %s - %s\n", argv[0], text[9], tmp3, strerror(errno));
                           exit (1);
-                        }
+                      }
                  }
                  fputs (bufz, fp_Download_Unsort);
 #endif
@@ -1192,7 +1263,7 @@ int main(argc,argv)
       if(sarglog)
          debuga(text[124]);
  
-      if((!common_log) && (!squid_log) && (!sarglog)) {
+      if((!common_log) && (!squid_log) && (!sarglog) && (!isalog)) {
          if(!totregsg) {
             fprintf(stderr, "SARG: %s\n",text[16]);
             fprintf(stderr, "SARG: %s\n",text[21]);
@@ -1271,7 +1342,7 @@ int main(argc,argv)
    sort_users_log(tmp, debug);
 
    if(strstr(ReportType,"denied") != 0) {
-      sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o %s %s", tmp, tmp5, tmp4);
+      sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o %s %s",tmp,tmp5,tmp4);
       system(csort);
       unlink(tmp4);
    }
@@ -1316,7 +1387,7 @@ void getusers(char *pwdfile, int debug)
    }
 
    if ((fp_usr = fopen(pwdfile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (getusers) %s: %s\n",text[45],pwdfile);
+      fprintf(stderr, "SARG: (getusers) %s: %s - %s\n",text[45],pwdfile,strerror(errno));
       exit(1);
    }
 
@@ -1358,7 +1429,7 @@ void gethexclude(char *hexfile, int debug)
    }
 
    if ((fp_ex = fopen(hexfile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (gethexclude) %s: %s\n",text[45],hexfile);
+      fprintf(stderr, "SARG: (gethexclude) %s: %s - %s\n",text[45],hexfile,strerror(errno));
       exit(1);
    }
 
@@ -1402,7 +1473,7 @@ void getuexclude(char *uexfile, int debug)
    }
 
    if ((fp_ex = fopen(uexfile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (gethexclude) %s: %s\n",text[45],uexfile);
+      fprintf(stderr, "SARG: (gethexclude) %s: %s - %s\n",text[45],uexfile,strerror(errno));
       exit(1);
    }
 
