@@ -54,8 +54,7 @@ void gerarel()
    sprintf(dirname, "%s%s", outdir, periodo);
    sprintf(wdir, "%s%s", outdir, periodo);
    strcpy(per1,periodo);
-   strcpy(wdirname,dirname);
-   vrfydir(wdir, wdirname, per1, addr, site, us, email);
+   vrfydir(wdir, per1, addr, site, us, email);
 
    if(debugz){
       debugaz("dirname",dirname);
@@ -63,7 +62,7 @@ void gerarel()
    }
  
    strcpy(wdirname,dirname);
-   gperiodo(wdirname, periodo);
+   gperiodo();
 
    if(strlen(UserAgentLog) > 0 && email[0] == '\0') 
       useragent();
@@ -442,7 +441,7 @@ void maketmp_hour(char *user, char *dirname, int indexonly)
 
    strcat(wdirname,".htmp");
    if((fp_ou=fopen(wdirname,"w"))==NULL){
-      fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
+      fprintf(stderr, "SARG: (report-1) %s: %s - %s\n",text[45],wdirname,strerror(errno));
       exit(1);
    }
 
@@ -511,7 +510,7 @@ void gravatmp_hora(char *dirname, char *user, char *data, char *hora, char *elap
    strcat(wdirname,".htmp");
 
    if((fp_ou=fopen(wdirname,"a"))==NULL){
-      fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
+      fprintf(stderr, "SARG: (report-2) %s: %s - %s\n",text[45],wdirname,strerror(errno));
       exit(1);
    }
 
