@@ -61,7 +61,7 @@ void siteuser()
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -k 4,4 -k 1,1 -o %s %s",geral2,geral);
+   sprintf(csort,"export LC_ALL=C;sort -k 4,4 -k 1,1 -o %s %s",geral2,geral);
    system(csort);
 
    if((fp_in=fopen(geral2,"r"))==NULL) {
