@@ -68,7 +68,7 @@ void smartfilter_report()
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -n -k 1,1 -k 2,2 -k 3,3 -o %s %s",smart_ou,smart_in);
+   sprintf(csort,"export LC_ALL=C;sort -n -k 1,1 -k 2,2 -k 3,3 -o %s %s",smart_ou,smart_in);
    system(csort);
    unlink(smart_in);
 
