@@ -94,7 +94,7 @@ void tmpsort()
          order[0]='\0';
         
       strcat(arqou,".txt");
-      sprintf(csort,"sort -n -T %s %s -k %s -k %s -k %s -o %s %s",TempDir,order,field1,field2,field3,arqou,arqin);
+      sprintf(csort,"export LC_ALL=C;sort -n -T %s %s -k %s -k %s -k %s -o %s %s",TempDir,order,field1,field2,field3,arqou,arqin);
       system(csort);
       unlink(arqin);
 
@@ -134,10 +134,10 @@ void sort_users_log(char *tmp, int debug)
       }
 
       if(strcmp(direntp->d_name,"download.unsort") == 0)
-         sprintf(csort,"sort -T %s -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o %s/%s.log %s/%s.unsort",
+         sprintf(csort,"export LC_ALL=C;sort -T %s -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o %s/%s.log %s/%s.unsort",
 					tmp, wtmp, user, wtmp, user);
       else
-         sprintf(csort,"sort -T %s -k 5,5 -k 1,1 -k 2,2 -o %s/%s.log %s/%s.unsort", 
+         sprintf(csort,"export LC_ALL=C;sort -T %s -k 5,5 -k 1,1 -k 2,2 -o %s/%s.log %s/%s.unsort", 
 					tmp, wtmp, user, wtmp, user);
       system(csort);
       sprintf(wdname,"%s/%s.unsort",wtmp,user);
