@@ -69,7 +69,7 @@ void topsites()
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -k 4,4 -o %s %s",geral2,geral);
+   sprintf(csort,"export LC_ALL=C;sort -k 4,4 -o %s %s",geral2,geral);
    system(csort);
 
    if((fp_in=fopen(geral2,"r"))==NULL) {
@@ -142,7 +142,7 @@ void topsites()
    if(strcmp(TopsitesSortType,"d") == 0)
       strcpy(sortt,"-r");
 
-   sprintf(csort,"sort %s -k %s -o %s %s",sortt,sortf,sites,geral3);
+   sprintf(csort,"export LC_ALL=C;sort %s -k %s -o %s %s",sortt,sortf,sites,geral3);
    system(csort);
 
    unlink(geral2);
