@@ -65,11 +65,6 @@ int topuser()
     exit(1);
    }
 
-   if((fp_top1=fopen(top1,"w"))==NULL) {
-      fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],top1);
-      exit(1);
-   }
-
    if((fp_top2=fopen(top2,"w"))==NULL) {
     fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],top2);
     exit(1);
@@ -174,8 +169,7 @@ int topuser()
    if(strcmp(TopuserSortOrder,"normal") == 0)
       order[0]='\0';
 
-
-   sprintf(csort,"sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
+   sprintf(csort,"export LC_ALL=C;sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
    system(csort);
 
    unlink(top2);
@@ -661,8 +655,6 @@ final:
    fclose(fp_top1);
    unlink(top1);
 
-   fclose(fp_top3);
-
    if((fp_ou=fopen(tusr,"w"))==NULL) {
       fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],tusr);
       exit(1);
@@ -672,7 +664,7 @@ final:
    fputs(preg,fp_ou);
 
    fputs("</body>\n</html>\n",fp_top3);
-
+   fclose(fp_top3);
    fclose(fp_ou);
 
    return;
