@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
- *                                                            1998, 2004
+ * AUTHOR: Pedro Lineu Orso                          orso@brturbo.com.br
+ *                                                            1998, 2005
  * SARG Squid Analysis Report Generator            http://sarg-squid.org
  * ---------------------------------------------------------------------
  *
@@ -46,8 +46,10 @@ void usage(char *prog)
   fprintf(stderr, "%5s-z %s\n"," ",text[35]);
   fprintf(stderr, "%5s-convert %s\n"," ",text[76]);
   fprintf(stderr, "%5s-split %s\n"," ",text[77]);
-  fprintf(stderr, "\n\t%s-%s %s Pedro Lineu Orso - orso@brturbo.com\n",PGM,VERSION,text[78]);
-  fprintf(stderr, "\thttp://www.sarg-squid.org\n\n");
+  fprintf(stderr, "\n\t%s-%s %s Pedro Lineu Orso - orso@brturbo.com.br\n",PGM,VERSION,text[78]);
+  fprintf(stderr, "\thttp://www.sarg-squid.org\n");
+  fprintf(stderr, "\n\tPease donate to the sarg project:");
+  fprintf(stderr, "\n\t\thttp://sarg.sourceforge.net/donations.php\n\n");
 
   return;
 }
