@@ -115,7 +115,7 @@ void useragent()
       debuga(msg);
    }
 
-   sprintf(csort,"sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o %s %s",tmp2,tmp);
+   sprintf(csort,"export LC_ALL=C;sort -n -t '\\' -k 4,4 -k 3,3 -k 2,2 -k 1,1 -o %s %s",tmp2,tmp);
    system(csort);
 
    unlink(tmp);
@@ -210,7 +210,7 @@ void useragent()
    fclose(fp_in);
    fclose(fp_ou);
 
-   sprintf(csort,"sort -n -t '\\' -k 3,3 -o %s %s",tmp,tmp2);
+   sprintf(csort,"export LC_ALL=C;sort -n -t '\\' -k 3,3 -o %s %s",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
@@ -258,7 +258,7 @@ void useragent()
 
    unlink(tmp);
 
-   sprintf(csort,"sort -n -r -k 1,1 -o %s %s",tmp,tmp2);
+   sprintf(csort,"export LC_ALL=C;sort -n -r -k 1,1 -o %s %s",tmp,tmp2);
    system(csort);
 
    unlink(tmp2);
