@@ -90,6 +90,20 @@ char *  getword2(char *word, char *line, int stop)
   return( line + x +1) ;
 }
 
+void getword3(char *word, char *line, int stop)
+{
+  int x = 0,y;
+  int loop=0;
+
+  for(x=0;((line[x]) && (line[x] != stop ));x++)
+     word[x] = line[x];
+  word[x] = '\0';
+  if(line[x]) ++x;
+    y=0;
+  while((line[y++] = line[x++]));
+}
+
+
 #ifdef LEGACY_MY_ATOLL
 
 // BMG (bguillory@email.com)
@@ -156,17 +170,35 @@ void my_mkdir(char *name)
    char w1[255];
    char w2[255];
 
+   if(strncmp(name,".",1) == 0 || strncmp(name,"/",1) != 0) {
+      fprintf(stderr,"SARG: Ivalid path (%s). Please, use absolute paths only.\n",name);
+      fprintf(stderr,"SARG: process aborted.\n");
+      exit(1);
+   }
+
    strcpy(w0,name);
    strcpy(w2,"/");
    getword(w1,w0,'/');
    while(strstr(w0,"/") != 0) {
       getword(w1,w0,'/');
       strcat(w2,w1);
-      mkdir(w2,0755);
+      if(access(w2, R_OK) != 0) {
+         if(mkdir(w2,0755)) {
+            fprintf(stderr,"SARG: mkdir %s %s\n",w2,strerror(errno));
+            fprintf(stderr,"SARG: process aborted.\n");
+            exit(1);
+         }
+      }
       strcat(w2,"/");
    }
    strcat(w2,w0);
-   mkdir(w2,0755);
+   if(access(w2, R_OK) != 0) {
+      if(mkdir(w2,0755)) {
+         fprintf(stderr,"SARG: mkdir %s %s\n",w2,strerror(errno));
+         fprintf(stderr,"SARG: process aborted.\n");
+         exit(1);
+      }
+   }
 }
 
 
@@ -190,11 +222,12 @@ void my_lltoa(unsigned long long int n, char s[], int len)
   }
   
   if(len) {
-     bzero(ww,50);
+     bzero(ww,sizeof(ww));
      i=len-strlen(s)-1;
      for(x=0; x<=i; x++)
         ww[x]='0';
-     strncat(ww,s,strlen(s));
+     i=strlen(s);
+     strncat(ww,s,i>sizeof(ww)?sizeof(ww):i);
      strcpy(s,ww);
   }
     
@@ -211,18 +244,21 @@ void builddia(char *dia, char *mes, char *ano, char *df, char *wdata)
    nmes[0]='\0';
 
    for(x=0; x<=12; x++) {
-      if(strcmp(mtab1[x],mes) == 0)
-         strcpy(nmes,mtab2[x]);
+      if(strcmp(mtab1[x],mes) == 0) {
+         strncpy(nmes,mtab2[x],sizeof(nmes)-1);
+         nmes[sizeof(nmes)-1]=0;
+      }
    }
 
-   sprintf(wdata,"%s%s%s",ano,nmes,dia);
+   snprintf(wdata,6,"%s%s%s",ano,nmes,dia);
 
    if(strncmp(df,"u",1) != 0)
-      sprintf(ndia,"%s/%s/%s",dia,nmes,ano);
+      snprintf(ndia,sizeof(ndia),"%s/%s/%s",dia,nmes,ano);
     else
-      sprintf(ndia,"%s/%s/%s",nmes,dia,ano);
+      snprintf(ndia,sizeof(ndia),"%s/%s/%s",nmes,dia,ano);
 
-   strcpy(dia,ndia);
+   strncpy(dia,ndia,sizeof(dia)-1);
+   dia[sizeof(dia)-1]=0;
 
    return;
 
@@ -262,6 +298,17 @@ void conv_month(char *month)
 }
 
 
+void conv_month_name(char *month)
+{
+   int x;
+
+   for(x=0; x<=12; x++) {
+      if(strcmp(mtab2[x],month) == 0)
+         strcpy(month,mtab1[x]);
+   }
+}
+
+
 void fixper(char *tbuf, char *periodo, char *duntil)
 {
 
@@ -539,7 +586,8 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
 }
 
 
-void gperiodo(char *dirname, const char *periodo)
+//void gperiodo(char *dirname, const char *periodo)
+void gperiodo()
 {
  
    FILE *fp_ou;
@@ -549,7 +597,7 @@ void gperiodo(char *dirname, const char *periodo)
    strcpy(wdirname,dirname);
    strcat(wdirname,"/");
    strcat(wdirname,"periodo");
- 
+
    if((fp_ou=fopen(wdirname,"w"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
       exit(1);
@@ -565,7 +613,7 @@ void gperiodo(char *dirname, const char *periodo)
  
 }
 
-void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char *us, char *form)
+void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form)
 {
    FILE *img_in, *img_ou;
    int  num=1, count=0;
@@ -578,32 +626,8 @@ void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char
    DIR *dirp;
    struct dirent *direntp;
 
-   strcpy(dirname2,dirname);
-   if(strcmp(OverwriteReport,"no") == 0) {
-      while(num) {
-         if(access(dirname,R_OK) == 0) {
-            sprintf(dirname,"%s.%d",dir,num);
-            sprintf(per2,"%s.%d",per1,num);
-            num++;
-            count++;
-         } else
-            break;
-      }
-   
-      if(count > 0) {
-         if(debug)
-            fprintf(stderr, "SARG: %s: %s %s %s\n",text[51],dir,text[52],dirname);
-         rename(dir,dirname);
-      }
-   } else {
-      if(access(dir,R_OK) == 0) {
-         sprintf(wdir,"rm -r %s",dir);
-         system(wdir);
-      }
-   }
-
-//   sprintf(wdir,"mkdir -p %s",dir);
    sprintf(wdir,"%s",dir);
+
    if(strlen(us) > 0) {
       strcat(wdir,"-");
       strcat(wdir,us);
@@ -617,39 +641,79 @@ void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char
       strcat(wdir,site);
    }
 
-   my_mkdir(wdir);
+   if(strcmp(dirname,wdir) != 0)
+      strcpy(dirname,wdir);
 
-   sprintf(dirname,"%s",wdir+9);
-   sprintf(images,"%s/images",outdir);
+   strcpy(dirname2,dirname);
+
+   if(strcmp(OverwriteReport,"no") == 0) {
+      while(num) {
+         if(access(wdir,R_OK) == 0) {
+            sprintf(wdir,"%s.%d",dirname,num);
+            sprintf(per2,"%s.%d",per1,num);
+            num++;
+            count++;
+         } else
+            break;
+      }
+
+      if(count > 0) {
+         if(debug)
+            fprintf(stderr, "SARG: %s: %s %s %s\n",text[51],dirname2,text[52],wdir);
+         rename(dirname2,wdir);
+      }
+   } else {
+      if(access(dir,R_OK) == 0) {
+         sprintf(csort,"rm -r %s",dir);
+         system(csort);
+      }
+   }
+
+   my_mkdir(dirname);
+
+   strcpy(dirname2,wdir);
+   sprintf(images,"%simages",outdir);
    mkdir(images,0755);
 
-   sprintf(wdir,"date >%s/%s",dirname2,"date");
+   sprintf(wdir,"date >%s/%s",dirname,"date");
    system(wdir);
 
    sprintf(per2,"%s/images",SYSCONFDIR);
+
    dirp = opendir(per2);
+   if(dirp==NULL) {
+      fprintf(stderr, "SARG: (util) %s %s: %s\n","Can't open directory", per2,strerror(errno));
+      return;
+   }
    while ((direntp = readdir( dirp )) != NULL ){
       if(strncmp(direntp->d_name,".",1) == 0)
          continue;
       sprintf(val10,"%s/%s",per2,direntp->d_name);
       sprintf(val11,"%s/%s",images,direntp->d_name);
       img_in = fopen(val10, "rb");
-      img_ou = fopen(val11, "wb");
-      while (c!=EOF) {
-         c = fgetc(img_in);
-         if(c==EOF) break;
-         fputc(c,img_ou);
-      }
-    
-      c=0;
+      if(img_in!=NULL) {
+         img_ou = fopen(val11, "wb");
+         if(img_ou!=NULL) {
+            while (c!=EOF) {
+               c = fgetc(img_in);
+               if(c==EOF) break;
+               fputc(c,img_ou);
+            }
+            c=0;
+            fclose(img_ou);
+         } else
+            fprintf(stderr,"SARG: (util): %s %s: %s\n", text[45]?text[45]:"Can't open/create file", val11, strerror(errno));
+      } else
+         fprintf(stderr,"SARG: (util): %s %s: %s\n", text[45]?text[45]:"Can't open file", val10, strerror(errno));
+
       fclose(img_in);
-      fclose(img_ou);
    }
    (void) rewinddir(dirp);
    (void) closedir(dirp);
 
    return;
 
+
 }
 
 
